/**
 * Copyright (c) 2010, 2020 Artem Tikhomirov, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *    Artem Tikhomirov (independent) - Initial API and implementation
 *    Michael Golubev (Montages) - #386838 - migrate to Xtend2
 *    Aurelien Didier (ARTAL) - aurelien.didier51@gmail.com - Bug 569174
 *    Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : L1.2 clean up parsers
 */
package parsers;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import impl.parsers.expression_qvto;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.CodeStyle;
import xpt.Common;

@Singleton
@SuppressWarnings("all")
public class ExpressionLabelParser {
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  @Extension
  private expression_qvto _expression_qvto;
  
  @Inject
  @Extension
  private ParsersUtil _parsersUtil;
  
  @Inject
  @Extension
  private CodeStyle _codeStyle;
  
  @Inject
  private impl.parsers.ExpressionLabelParser xptImplExpressionLabelParser;
  
  public CharSequence className(final org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _classNameExpressionLabelParser = this._parsersUtil.classNameExpressionLabelParser(it);
    _builder.append(_classNameExpressionLabelParser);
    return _builder;
  }
  
  public CharSequence packageName(final org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _packageNameExpressionLabelParser = this._parsersUtil.packageNameExpressionLabelParser(it);
    _builder.append(_packageNameExpressionLabelParser);
    return _builder;
  }
  
  public CharSequence qualifiedClassName(final org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(".");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    return _builder;
  }
  
  public CharSequence fullPath(final org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _qualifiedClassName = this.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    return _builder;
  }
  
  public CharSequence Main(final org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _copyright = this._common.copyright(it.getHolder().getEditorGen());
    _builder.append(_copyright);
    _builder.newLineIfNotEmpty();
    _builder.append("package ");
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _generatedClassComment = this._common.generatedClassComment();
    _builder.append(_generatedClassComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    _builder.append(" ");
    CharSequence _extendsList = this.extendsList(it);
    _builder.append(_extendsList);
    _builder.append(" ");
    CharSequence _implementsList = this.implementsList(it);
    _builder.append(_implementsList);
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _constructor = this.xptImplExpressionLabelParser.constructor(it, this.className(it).toString());
    _builder.append(_constructor, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _body = this.body(it);
    _builder.append(_body, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence extendsList(final org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _isParserViewExpressionDefinedAndOcl = this._expression_qvto.isParserViewExpressionDefinedAndOcl(it);
      if (_isParserViewExpressionDefinedAndOcl) {
        _builder.append("extends org.eclipse.gmf.tooling.runtime.parsers.ExpressionLabelParserBase");
      }
    }
    return _builder;
  }
  
  public CharSequence implementsList(final org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _isParserViewExpressionDefinedAndOcl = this._expression_qvto.isParserViewExpressionDefinedAndOcl(it);
      boolean _not = (!_isParserViewExpressionDefinedAndOcl);
      if (_not) {
        _builder.append("implements org.eclipse.gmf.runtime.common.ui.services.parser.IParser");
      }
    }
    return _builder;
  }
  
  public CharSequence body(final org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _isParserViewExpressionDefinedAndOcl = this._expression_qvto.isParserViewExpressionDefinedAndOcl(it);
      if (_isParserViewExpressionDefinedAndOcl) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        CharSequence _overrideC = this._codeStyle.overrideC(it);
        _builder.append(_overrideC);
        _builder.newLineIfNotEmpty();
        _builder.append("protected String getExpressionBody() {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("return ");
        CharSequence _expression = this.xptImplExpressionLabelParser.getExpression(it.getViewExpression().getProvider(), it, it.getViewExpression());
        _builder.append(_expression, "\t");
        _builder.append(".body();");
        _builder.newLineIfNotEmpty();
        _builder.append("}");
        _builder.newLine();
      } else {
        CharSequence _generatedMemberComment_1 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_1);
        _builder.newLineIfNotEmpty();
        _builder.append("public String getPrintString(org.eclipse.core.runtime.IAdaptable element, int flags) {");
        _builder.newLine();
        _builder.append("\t");
        CharSequence _accessViewExpression = this.xptImplExpressionLabelParser.accessViewExpression(it);
        _builder.append(_accessViewExpression, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("}");
        _builder.newLine();
        _builder.newLine();
        CharSequence _generatedMemberComment_2 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_2);
        _builder.newLineIfNotEmpty();
        _builder.append("public boolean isAffectingEvent(Object event, int flags) {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("// XXX Any event is recognized as important, unless there\'s a way to extract this information from expression itself.");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("// TODO analyze expressions (e.g. using OCL parser) to find out structural features in use  ");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("return true;");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    _builder.newLine();
    CharSequence _generatedMemberComment_3 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_3);
    _builder.newLineIfNotEmpty();
    _builder.append("public String getEditString(org.eclipse.core.runtime.IAdaptable element, int flags) {");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _accessEditExpression = this.xptImplExpressionLabelParser.accessEditExpression(it);
    _builder.append(_accessEditExpression, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_4 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_4);
    _builder.newLineIfNotEmpty();
    _builder.append("public org.eclipse.gmf.runtime.common.ui.services.parser.IParserEditStatus isValidEditString(org.eclipse.core.runtime.IAdaptable element, String editString) {");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _accessValidateExpression = this.xptImplExpressionLabelParser.accessValidateExpression(it);
    _builder.append(_accessValidateExpression, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_5 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_5);
    _builder.newLineIfNotEmpty();
    _builder.append("public org.eclipse.gmf.runtime.common.core.command.ICommand getParseCommand(org.eclipse.core.runtime.IAdaptable element, final String newString, int flags) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("final org.eclipse.emf.ecore.EObject target = element.getAdapter(org.eclipse.emf.ecore.EObject.class);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (!validateValues(target, newString)) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return org.eclipse.gmf.runtime.common.core.command.UnexecutableCommand.INSTANCE;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.eclipse.emf.transaction.TransactionalEditingDomain editingDomain = org.eclipse.emf.transaction.util.TransactionUtil.getEditingDomain(target);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (editingDomain == null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return org.eclipse.gmf.runtime.common.core.command.UnexecutableCommand.INSTANCE;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.eclipse.core.resources.IFile affectedFile = org.eclipse.emf.workspace.util.WorkspaceSynchronizer.getFile(target.eResource());");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return new org.eclipse.gmf.runtime.emf.commands.core.command.AbstractTransactionalCommand(editingDomain, \"Set Values\", affectedFile == null ? null : java.util.Collections.singletonList(affectedFile)) { ");
    CharSequence _nonNLS = this._common.nonNLS(1);
    _builder.append(_nonNLS, "\t");
    _builder.append(" ");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("protected org.eclipse.gmf.runtime.common.core.command.CommandResult doExecuteWithResult(org.eclipse.core.runtime.IProgressMonitor monitor, org.eclipse.core.runtime.IAdaptable info) throws org.eclipse.core.commands.ExecutionException {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("return new org.eclipse.gmf.runtime.common.core.command.CommandResult(updateValues(target, newString));");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("};");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_6 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_6);
    _builder.newLineIfNotEmpty();
    _builder.append("public org.eclipse.jface.text.contentassist.IContentAssistProcessor getCompletionProcessor(org.eclipse.core.runtime.IAdaptable element) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return null;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_7 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_7);
    _builder.newLineIfNotEmpty();
    _builder.append("private boolean validateValues(org.eclipse.emf.ecore.EObject target, String newString) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("// TODO implement as needed");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return true;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_8 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_8);
    _builder.newLineIfNotEmpty();
    _builder.append("private org.eclipse.core.runtime.IStatus updateValues(org.eclipse.emf.ecore.EObject target, String newString) throws org.eclipse.core.commands.ExecutionException {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("// TODO implement this method");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("// DO NOT FORGET to remove @generated tag or mark method @generated NOT");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("throw new org.eclipse.core.commands.ExecutionException(\"Please implement parsing and value modification\"); ");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    CharSequence _extraMethods = this.xptImplExpressionLabelParser.extraMethods(it);
    _builder.append(_extraMethods);
    _builder.newLineIfNotEmpty();
    return _builder;
  }
}
